==> ejc-settle-impl-3.0.0-20240617.022532-42-sources.jar: com/ejianc/business/settle/vo/SettlementCenterAlertInfoVO.java <==
package com.ejianc.business.settle.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 预警信息表
 * 
 * @author generator
 * 
 */
public class SettlementCenterAlertInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long id; // 主键id
    private Long thirdNodeUserId; // 结算中心专职(被预警人)
    private Integer dr; // '删除标识（0：未删，1：删除）'
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String dcDrwgrpInfoName; // 卷册名称
    private Date createTime; // 创建时间
    private Date updateTime; // 修改时间
    private Long settlementCenterMajor; // 结算中心专业
    private Date alertLastTime; // 24小时预警时间
    private Date alertNowTime; // 截止时间
    private Integer alertType; // '预警类型（0：24h预警，1：截止日期预警）'
    private Long tenantId; // 租户主键
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Integer billState; // 单据状态
    private String thirdNodeUserName; // 节点3结算中心专职人员名字


    public String getThirdNodeUserName() {
        return thirdNodeUserName;
    }

    public void setThirdNodeUserName(String thirdNodeUserName) {
        this.thirdNodeUserName = thirdNodeUserName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    @Override
    public Long getTenantId() {
        return tenantId;
    }

    @Override
    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public Long getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(Long thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @Override
    public Date getUpdateTime() {
        return updateTime;
    }

    @Override
    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }

    public Date getAlertLastTime() {
        return alertLastTime;
    }

    public void setAlertLastTime(Date alertLastTime) {
        this.alertLastTime = alertLastTime;
    }

    public Date getAlertNowTime() {
        return alertNowTime;
    }

    public void setAlertNowTime(Date alertNowTime) {
        this.alertNowTime = alertNowTime;
    }

    public Integer getAlertType() {
        return alertType;
    }

    public void setAlertType(Integer alertType) {
        this.alertType = alertType;
    }
}

==> ejc-settle-impl-3.0.0-20240708.072402-71-sources.jar: com/ejianc/business/settle/vo/SettlementCenterAlertInfoVO.java <==
package com.ejianc.business.settle.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 预警信息表
 * 
 * @author generator
 * 
 */
public class SettlementCenterAlertInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long id; // 主键id
    private String thirdNodeUserId; // 结算中心专职(被预警人)
    private Integer dr; // '删除标识（0：未删，1：删除）'
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String dcDrwgrpInfoName; // 卷册名称
    private Date createTime; // 创建时间
    private Date updateTime; // 修改时间
    private Long settlementCenterMajor; // 结算中心专业
    private Date alertLastTime; // 24小时预警时间
    private Date alertNowTime; // 截止时间
    private Integer alertType; // '预警类型（0：24h预警，1：截止日期预警）'
    private Long tenantId; // 租户主键
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Integer billState; // 单据状态
    private String thirdNodeUserName; // 节点3结算中心专职人员名字


    public String getThirdNodeUserName() {
        return thirdNodeUserName;
    }

    public void setThirdNodeUserName(String thirdNodeUserName) {
        this.thirdNodeUserName = thirdNodeUserName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    @Override
    public Long getTenantId() {
        return tenantId;
    }

    @Override
    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    public String getThirdNodeUserId() {
        return thirdNodeUserId;
    }

    public void setThirdNodeUserId(String thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoName() {
        return dcDrwgrpInfoName;
    }

    public void setDcDrwgrpInfoName(String dcDrwgrpInfoName) {
        this.dcDrwgrpInfoName = dcDrwgrpInfoName;
    }

    @Override
    public Date getCreateTime() {
        return createTime;
    }

    @Override
    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    @Override
    public Date getUpdateTime() {
        return updateTime;
    }

    @Override
    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Long getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(Long settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }

    public Date getAlertLastTime() {
        return alertLastTime;
    }

    public void setAlertLastTime(Date alertLastTime) {
        this.alertLastTime = alertLastTime;
    }

    public Date getAlertNowTime() {
        return alertNowTime;
    }

    public void setAlertNowTime(Date alertNowTime) {
        this.alertNowTime = alertNowTime;
    }

    public Integer getAlertType() {
        return alertType;
    }

    public void setAlertType(Integer alertType) {
        this.alertType = alertType;
    }
}
